==> config-api-0.3.10-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/SecuritySetting.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
/**
 * A security setting allows sets of permissions to be defined against queues based on their address.
 */
@ResourceType("security-setting")
public class SecuritySetting<T extends SecuritySetting> {

	private String key;
	private SecuritySettingResources subresources = new SecuritySettingResources();

	public SecuritySetting(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	public SecuritySettingResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all org.wildfly.swarm.config.messaging_activemq.server.Role objects to this subresource
	 * @return this
	 * @param value List of org.wildfly.swarm.config.messaging_activemq.server.Role objects.
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting roles(
			List<org.wildfly.swarm.config.messaging_activemq.server.Role> value) {
		this.subresources.roles.addAll(value);
		return (SecuritySetting) this;
	}

	/**
	 * Add the org.wildfly.swarm.config.messaging_activemq.server.Role object to the list of subresources
	 * @param value The org.wildfly.swarm.config.messaging_activemq.server.Role to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting role(Role value) {
		this.subresources.roles.add(value);
		return (SecuritySetting) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.messaging_activemq.server.Role object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.messaging_activemq.server.Role resource
	 * @param config The org.wildfly.swarm.config.messaging_activemq.server.RoleConfigurator to use
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting role(String childKey, RoleConfigurator config) {
		org.wildfly.swarm.config.messaging_activemq.server.Role child = new org.wildfly.swarm.config.messaging_activemq.server.Role(
				childKey);
		if (config != null) {
			config.configure(child);
		}
		role(child);
		return (SecuritySetting) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.messaging_activemq.server.Role object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.messaging_activemq.server.Role resource
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting role(String childKey) {
		role(childKey, null);
		return (SecuritySetting) this;
	}

	/**
	 * Child mutators for SecuritySetting
	 */
	public class SecuritySettingResources {
		/**
		 * A security role.
		 */
		private List<org.wildfly.swarm.config.messaging_activemq.server.Role> roles = new java.util.ArrayList<>();

		/**
		 * Get the list of org.wildfly.swarm.config.messaging_activemq.server.Role resources
		 * @return the list of resources
		 */
		@Subresource
		public List<Role> roles() {
			return this.roles;
		}
	}
}

==> config-api-0.3.11-sources.jar: org/wildfly/swarm/config/messaging_activemq/server/SecuritySetting.java <==
package org.wildfly.swarm.config.messaging_activemq.server;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.List;
import org.wildfly.swarm.config.runtime.Subresource;
/**
 * A security setting allows sets of permissions to be defined against queues based on their address.
 */
@ResourceType("security-setting")
public class SecuritySetting<T extends SecuritySetting> {

	private String key;
	private SecuritySettingResources subresources = new SecuritySettingResources();

	public SecuritySetting(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	public SecuritySettingResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all org.wildfly.swarm.config.messaging_activemq.server.Role objects to this subresource
	 * @return this
	 * @param value List of org.wildfly.swarm.config.messaging_activemq.server.Role objects.
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting roles(
			List<org.wildfly.swarm.config.messaging_activemq.server.Role> value) {
		this.subresources.roles = value;
		return (SecuritySetting) this;
	}

	/**
	 * Add the org.wildfly.swarm.config.messaging_activemq.server.Role object to the list of subresources
	 * @param value The org.wildfly.swarm.config.messaging_activemq.server.Role to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting role(Role value) {
		this.subresources.roles.add(value);
		return (SecuritySetting) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.messaging_activemq.server.Role object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.messaging_activemq.server.Role resource
	 * @param config The org.wildfly.swarm.config.messaging_activemq.server.RoleConfigurator to use
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting role(String childKey, RoleConfigurator config) {
		org.wildfly.swarm.config.messaging_activemq.server.Role child = new org.wildfly.swarm.config.messaging_activemq.server.Role(
				childKey);
		if (config != null) {
			config.configure(child);
		}
		role(child);
		return (SecuritySetting) this;
	}

	/**
	 * Create and configure a org.wildfly.swarm.config.messaging_activemq.server.Role object to the list of subresources
	 * @param key The key for the org.wildfly.swarm.config.messaging_activemq.server.Role resource
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public SecuritySetting role(String childKey) {
		role(childKey, null);
		return (SecuritySetting) this;
	}

	/**
	 * Child mutators for SecuritySetting
	 */
	public class SecuritySettingResources {
		/**
		 * A security role.
		 */
		private List<org.wildfly.swarm.config.messaging_activemq.server.Role> roles = new java.util.ArrayList<>();

		/**
		 * Get the list of org.wildfly.swarm.config.messaging_activemq.server.Role resources
		 * @return the list of resources
		 */
		@Subresource
		public List<Role> roles() {
			return this.roles;
		}
	}
}
